@@ -150,9 +150,6 @@ def categorizeSections(topTrends, script, pageStart):
             isTransition = content["segment"][0]["x"] >= 420 or "FADE" in text or "CUT" in text or "TO:" in text
             isAction = abs(x - topTrends[0][0]) <= 15
 
-            if "Would you be so kind as to read" in content["segment"][0]["text"]:
-                x = 0
-
             if isHeading(content["segment"][0]):
                 sceneNumber += 1
                 if len(finalSections[-1]["content"][-1]["scene"]) == 0:
